# ExternalIDV30Rc1

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**external_id_type** | **str** |  | 
**external_id_value** | **str** |  | 
**external_id_normalized** | [**TransientNonEmptyString**](TransientNonEmptyString.md) |  | [optional] 
**external_id_normalized_error** | [**TransientError**](TransientError.md) |  | [optional] 
**external_id_url** | [**UrlV30Rc1**](UrlV30Rc1.md) |  | [optional] 
**external_id_relationship** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

